<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright EB Dynamics, Inc., Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 10/12/2010	ELL
// Revised: 2/8/2012	ELL
// Added table prefix handling.
// 
	
	include ("check_session.php");

	$prune_page_bkup_days = $_REQUEST['prune_page_bkup_days'];
	$query = "DELETE FROM " . BWB_TABLE_PREFIX . "page_data_bkup WHERE DATE_SUB(CURDATE(),INTERVAL $prune_page_bkup_days DAY) > `revised`";
	$cnt = $bwb_dbh->exec($query);
	
	header("Location: main.php?mode=admin");
?>
